=== modified file 'client/drizzle.cc'
--- client/drizzle.cc	2010-10-03 21:08:21 +0000
+++ client/drizzle.cc	2010-10-06 15:14:53 +0000
@@ -287,7 +287,7 @@
   connected= false, opt_raw_data= false, unbuffered= false,
   output_tables= false, opt_rehash= true, skip_updates= false,
   safe_updates= false, one_database= false,
-  opt_compress= false, opt_shutdown= false, opt_ping= false,
+  opt_shutdown= false, opt_ping= false,
   vertical= false, line_numbers= true, column_names= true,
   opt_nopager= true, opt_outfile= false, named_cmds= false,
   opt_nobeep= false, opt_reconnect= true,
@@ -1287,8 +1287,6 @@
   N_("Display column type information."))
   ("comments,c", po::value<bool>(&preserve_comments)->default_value(false)->zero_tokens(),
   N_("Preserve comments. Send comments to the server. The default is --skip-comments (discard comments), enable with --comments"))
-  ("compress,C", po::value<bool>(&opt_compress)->default_value(false)->zero_tokens(),
-  N_("Use compression in server/client protocol."))  
   ("vertical,E", po::value<bool>(&vertical)->default_value(false)->zero_tokens(),
   N_("Print the output of a query (rows) vertically."))
   ("force,f", po::value<bool>(&ignore_errors)->default_value(false)->zero_tokens(),
@@ -1326,7 +1324,7 @@
 
   po::options_description drizzle_options(N_("Options specific to the drizzle client"));
   drizzle_options.add_options()
-  ("disable-auto-rehash",
+  ("disable-auto-rehash,A",
   N_("Disable automatic rehashing. One doesn't need to use 'rehash' to get table and field completion, but startup and reconnecting may take a longer time."))
   ("auto-vertical-output", po::value<bool>(&auto_vertical_output)->default_value(false)->zero_tokens(),
   N_("Automatically switch to vertical output mode if the result is wider than the terminal width."))

=== modified file 'client/drizzledump.cc'
--- client/drizzledump.cc	2010-10-02 21:15:42 +0000
+++ client/drizzledump.cc	2010-10-06 07:31:26 +0000
@@ -78,10 +78,12 @@
 #define IGNORE_DATA 0x01 /* don't dump data for this table */
 #define IGNORE_INSERT_DELAYED 0x02 /* table doesn't support INSERT DELAYED */
 
+bool opt_alltspcs= false;
+bool opt_complete_insert= false;
 bool  verbose= false;
 static bool use_drizzle_protocol= false;
 bool ignore_errors= false;
-bool opt_compress= false;
+static bool flush_logs= false;
 static bool create_options= true; 
 static bool opt_quoted= false;
 bool opt_databases= false; 
@@ -465,8 +467,12 @@
   commandline_options.add_options()
   ("all-databases,A", po::value<bool>(&opt_alldbs)->default_value(false)->zero_tokens(),
   N_("Dump all the databases. This will be same as --databases with all databases selected."))
-  ("compress,C", po::value<bool>(&opt_compress)->default_value(false)->zero_tokens(),
-  N_("Use compression in server/client protocol."))
+  ("all-tablespaces,Y", po::value<bool>(&opt_alltspcs)->default_value(false)->zero_tokens(),
+  N_("Dump all the tablespaces."))
+  ("complete-insert,c", po::value<bool>(&opt_complete_insert)->default_value(false)->zero_tokens(),
+  N_("Use complete insert statements."))
+  ("flush-logs,F", po::value<bool>(&flush_logs)->default_value(false)->zero_tokens(),
+  N_("Flush logs file in server before starting dump. Note that if you dump many databases at once (using the option --databases= or --all-databases), the logs will be flushed for each database dumped. The exception is when using --lock-all-tables in this case the logs will be flushed only once, corresponding to the moment all tables are locked. So if you want your dump and the log flush to happen at the same exact moment you should use --lock-all-tables or --flush-logs"))
   ("force,f", po::value<bool>(&ignore_errors)->default_value(false)->zero_tokens(),
   N_("Continue even if we get an sql-error."))
   ("help,?", N_("Display this help message and exit."))

=== modified file 'client/drizzletest.cc'
--- client/drizzletest.cc	2010-09-26 08:33:47 +0000
+++ client/drizzletest.cc	2010-10-02 09:18:42 +0000
@@ -3846,7 +3846,7 @@
 {
   uint32_t con_port= opt_port;
   const char *con_options;
-  bool con_ssl= 0, con_compress= 0;
+  bool con_ssl= 0;
   struct st_connection* con_slot;
 
   string ds_connection_name;
@@ -3912,8 +3912,6 @@
       end++;
     if (!strncmp(con_options, "SSL", 3))
       con_ssl= 1;
-    else if (!strncmp(con_options, "COMPRESS", 8))
-      con_compress= 1;
     else
       die("Illegal option to connect: %.*s",
           (int) (end - con_options), con_options);

=== modified file 'docs/clients/drizzledump.rst'
--- docs/clients/drizzledump.rst	2010-09-29 11:24:25 +0000
+++ docs/clients/drizzledump.rst	2010-10-06 07:31:26 +0000
@@ -35,12 +35,6 @@
    *data_dictionary* in Drizzle and *information_schema*, *performance_schema*
    and *mysql* in MySQL.
 
-.. option:: -C, --compress
-
-   Use client/server compression protocol.
-
-   **NOTE:** this option is not currently implemented.
-
 .. option:: -f, --force
 
    Continue even if we get an sql-error.

=== modified file 'drizzled/base.h'
--- drizzled/base.h	2010-09-22 19:06:14 +0000
+++ drizzled/base.h	2010-10-05 03:25:08 +0000
@@ -473,21 +473,23 @@
 */
 #define NULL_RANGE	64
 
-typedef struct st_key_range
+class key_range
 {
+public:
   const unsigned char *key;
   uint32_t length;
   enum ha_rkey_function flag;
   key_part_map keypart_map;
-} key_range;
+};
 
-typedef struct st_key_multi_range
+class KEY_MULTI_RANGE
 {
+public:
   key_range start_key;
   key_range end_key;
   char  *ptr;                 /* Free to use by caller (ptr to row etc) */
   uint32_t  range_flag;           /* key range flags see above */
-} KEY_MULTI_RANGE;
+};
 
 
 /* For number of records */

=== renamed file 'm4/pandora_have_libinnodb.m4' => 'm4/pandora_have_libhaildb.m4'
--- m4/pandora_have_libinnodb.m4	2010-09-19 18:20:17 +0000
+++ m4/pandora_have_libhaildb.m4	2010-10-05 06:47:41 +0000
@@ -3,58 +3,41 @@
 dnl gives unlimited permission to copy and/or distribute it,
 dnl with or without modifications, as long as this notice is preserved.
 
-AC_DEFUN([_PANDORA_SEARCH_LIBINNODB],[
+AC_DEFUN([_PANDORA_SEARCH_LIBHAILDB],[
   AC_REQUIRE([AC_LIB_PREFIX])
 
   dnl --------------------------------------------------------------------
-  dnl  Check for libhaildb or libinnodb
+  dnl  Check for libhaildb
   dnl --------------------------------------------------------------------
 
-  AC_ARG_ENABLE([libinnodb],
-    [AS_HELP_STRING([--disable-libinnodb],
-      [Build with libinnodb support @<:@default=on@:>@])],
-    [ac_enable_libinnodb="$enableval"],
-    [ac_enable_libinnodb="yes"])
-
-
-  AS_IF([test "x$ac_enable_libinnodb" = "xyes"],[
+  AC_ARG_ENABLE([libhaildb],
+    [AS_HELP_STRING([--disable-libhaildb],
+      [Build with libhaildb support @<:@default=on@:>@])],
+    [ac_enable_libhaildb="$enableval"],
+    [ac_enable_libhaildb="yes"])
+
+
+  AS_IF([test "x$ac_enable_libhaildb" = "xyes"],[
     AC_LIB_HAVE_LINKFLAGS(haildb,,[
       #include <haildb.h>
     ],[
-      ib_u64_t
-      ib_api_version(void);
+      ib_set_panic_handler(NULL);
     ])
     AS_IF([test "x${ac_cv_libhaildb}" = "xyes"],[
       AC_DEFINE([HAVE_HAILDB_H],[1],[Do we have haildb.h])
-      INNODB_LIBS="${LTLIBHAILDB}"
-      ac_cv_have_innodb=yes
-    ],[
-      AC_LIB_HAVE_LINKFLAGS(innodb,,[
-        #include <embedded_innodb-1.0/innodb.h>
-      ],[
-        ib_u64_t
-        ib_api_version(void);
-      ])
-      AS_IF([test "x${ac_cv_libinnodb}" = "xyes"],[
-        AC_DEFINE([HAVE_INNODB_H],[1],[Do we have innodb.h])
-        INNODB_LIBS="${LTLIBINNODB}"
-        ac_cv_have_innodb=yes
-      ])
-    ])
+      ])
   ],[
     ac_cv_libhaildb="no"
-    ac_cv_libinnodb="no"
   ])
-  AC_SUBST([INNODB_LIBS])
-  AM_CONDITIONAL(HAVE_LIBINNODB, [test "x${ac_cv_have_innodb}" = "xyes"])
-])
-
-AC_DEFUN([PANDORA_HAVE_LIBINNODB],[
-  AC_REQUIRE([_PANDORA_SEARCH_LIBINNODB])
-])
-
-AC_DEFUN([PANDORA_REQUIRE_LIBINNODB],[
-  AC_REQUIRE([PANDORA_HAVE_LIBINNODB])
-  AS_IF([test "x${ac_cv_libinnodb}" = "xno"],
-      AC_MSG_ERROR([libhaildb or libinnodb is required for ${PACKAGE}]))
+  AM_CONDITIONAL(HAVE_LIBHAILDB, [test "x${ac_cv_libhaildb}" = "xyes"])
+])
+
+AC_DEFUN([PANDORA_HAVE_LIBHAILDB],[
+  AC_REQUIRE([_PANDORA_SEARCH_LIBHAILDB])
+])
+
+AC_DEFUN([PANDORA_REQUIRE_LIBHAILDB],[
+  AC_REQUIRE([PANDORA_HAVE_LIBHAILDB])
+  AS_IF([test "x${ac_cv_libhaildb}" = "xno"],
+      AC_MSG_ERROR([libhaildb 2.2.0 or later is required for ${PACKAGE}]))
 ])

=== modified file 'plugin/haildb/plugin.ac'
--- plugin/haildb/plugin.ac	2010-02-08 03:36:14 +0000
+++ plugin/haildb/plugin.ac	2010-10-05 06:47:41 +0000
@@ -1,1 +1,1 @@
-PANDORA_HAVE_LIBINNODB
\ No newline at end of file
+PANDORA_HAVE_LIBHAILDB

=== modified file 'plugin/haildb/plugin.ini'
--- plugin/haildb/plugin.ini	2010-09-30 05:47:49 +0000
+++ plugin/haildb/plugin.ini	2010-10-05 06:47:41 +0000
@@ -4,5 +4,5 @@
 sources=haildb_engine.cc haildb_version_func.cc haildb_datadict_dump_func.cc config_table_function.cc status_table_function.cc datadict_table_message.cc
 headers=haildb_engine.h haildb_version_func.h haildb_datadict_dump_func.h config_table_function.h status_table_function.h
 build_conditional="x${ac_cv_have_innodb}" = "xyes"
-ldflags=${INNODB_LIBS}
+ldflags=${LTLIBHAILDB}
 extra_dist=test-suite-dir

